

class CollectionsUtil:

    @classmethod
    def deep_args_to_list(cls, *args) -> list:
        args_list = []

        for arg in args:
            args_list.extend(cls.__args_to_list_recursive(arg))

        return args_list

    @staticmethod
    def is_iter(obj) -> bool:
        try:
            iter(obj)
        except TypeError:
            return False

        return True

    @classmethod
    def __args_to_list_recursive(cls, arg):
        args_list = []

        if cls.is_iter(arg) and not isinstance(arg, str):
            for a in arg:
                args_list.extend(cls.__args_to_list_recursive(a))
        else:
            args_list.append(arg)

        return args_list





class ListUtil:
    @staticmethod
    def compare_lists(list_1: list, list_2: list) -> bool:
        if len(list_1) != len(list_2):
            return False

        for item in list_1:
            if item not in list_2:
                return False

        for item in list_2:
            if item not in list_1:
                return False

        return True

    @staticmethod
    def remove_none(list_: list):
        return [x for x in list_ if x is not None]

    @staticmethod
    def remove_duplicates(list_: list):
        return list(set(list_))



from typing import Optional

import pytest
from coverage import Coverage


class TestsSuite:
    CONFIG_FILE = ".coveragerc"

    is_tests_suite_run: bool = False
    log_file_path: Optional[str] = None

    __coverage: Optional[Coverage] = None
    __is_coverage: bool

    def __init__(self, is_coverage: bool = False):
        self.__coverage = Coverage(config_file=self.CONFIG_FILE)
        self.__is_coverage = is_coverage
        TestsSuite.is_tests_suite_run = True

    def run_tests(self):
        if self.__is_coverage:
            self.__coverage.start()

        pytest.main(['-x', './tests'])

        if self.__is_coverage:
            self.__coverage.stop()

    def create_report(self):
        self.__coverage.report()
        self.__coverage.json_report()
        self.__coverage.lcov_report()
        self.__coverage.html_report()

    def erase_data(self):
        self.__coverage.erase()



import os
from setuptools import setup

import nrt_collections_utils

PATH = os.path.dirname(__file__)

with open(os.path.join(PATH, 'requirements.txt')) as f:
    requirements = f.read().splitlines()

with open(os.path.join(PATH, 'README.md')) as f:
    readme = f.read()

setup(
    name='nrt-collections-utils',
    version=nrt_collections_utils.__version__,
    author='Eyal Tuzon',
    author_email='eyal.tuzon.dev@gmail.com',
    description='Collection utilities in Python',
    keywords='python python3 python-3 tool tools'
             ' collection collections utilities utils util'
             ' nrt nrt-utils collections-utils collections-utilities'
             ' nrt-collections-utils nrt-collections-utilities'
             ' list list-utils list-utilities nrt-list-utils nrt-list-utilities',
    long_description_content_type='text/markdown',
    long_description=readme,
    url='https://github.com/etuzon/python-nrt-collections-utils',
    packages=['nrt_collections_utils'],
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=[requirements],
    data_files=[('', ['requirements.txt'])],
)
